Panda3D REST
============
![GitHub issues](https://img.shields.io/github/issues/NxtStudios/p3d-rest?style=for-the-badge)
![PyPI - Status](https://img.shields.io/pypi/status/panda3d_rest?style=for-the-badge)
![Engine](https://img.shields.io/static/v1?style=for-the-badge&label=Engine&message=Panda3D&color=red)

p3d-rest provides a panda native solution to performing RESTful HTTP GET/POST requests using non-blocking io.

### Requirements

- The Panda3D SDK (get it <a href="http://www.panda3d.org/download.php?sdk">here</a>)

## License
Panda3D REST is licensed under the MIT license. See the provided LICENSE file for details.
